summaryrefslogtreecommitdiff
path: root/actions/publictagcloud.php
diff options
context:
space:
mode:
Diffstat (limited to 'actions/publictagcloud.php')
-rw-r--r--actions/publictagcloud.php20
1 files changed, 10 insertions, 10 deletions
diff --git a/actions/publictagcloud.php b/actions/publictagcloud.php
index e9f33d58b..e7f6ee36c 100644
--- a/actions/publictagcloud.php
+++ b/actions/publictagcloud.php
@@ -1,6 +1,6 @@
<?php
/**
* Laconica, the distributed open-source microblogging tool
*
* Public tag cloud for notices
*
@@ -20,16 +20,16 @@
* along with this program. If not, see <http://www.gnu.org/licenses/>.
*
* @category Public
- * @package Laconica
+ * @package StatusNet
* @author Mike Cochrane <mikec@mikenz.geek.nz>
- * @author Evan Prodromou <evan@controlyourself.ca>
+ * @author Evan Prodromou <evan@status.net>
* @copyright 2008 Mike Cochrane
- * @copyright 2008-2009 Control Yourself, Inc.
+ * @copyright 2008-2009 StatusNet, Inc.
* @license http://www.fsf.org/licensing/licenses/agpl-3.0.html GNU Affero General Public License version 3.0
- * @link http://laconi.ca/
+ * @link http://status.net/
*/
-if (!defined('LACONICA')) { exit(1); }
+if (!defined('STATUSNET') && !defined('LACONICA')) { exit(1); }
define('TAGS_PER_PAGE', 100);
@@ -37,12 +37,12 @@ define('TAGS_PER_PAGE', 100);
* Public tag cloud for notices
*
* @category Personal
- * @package Laconica
+ * @package StatusNet
* @author Mike Cochrane <mikec@mikenz.geek.nz>
- * @author Evan Prodromou <evan@controlyourself.ca>
+ * @author Evan Prodromou <evan@status.net>
* @copyright 2008 Mike Cochrane
- * @copyright 2008-2009 Control Yourself, Inc.
- * @link http://laconi.ca/
+ * @copyright 2008-2009 StatusNet, Inc.
+ * @link http://status.net/
*/
class PublictagcloudAction extends Action
@@ -1,6 +1,6 @@
<?php
/**
- * Laconica, the distributed open-source microblogging tool
+ * StatusNet, the distributed open-source microblogging tool
*
* Public tag cloud for notices